@@ -31,15 +31,21 @@ file_check()
         exit 1
      fi
 
-     if [ ! -f snare.conf.workstation ]
+     if [ ! -f snare.conf.basic ]
      then
-        echo "The new workstation configuration file is missing. Terminating script."
+        echo "The new basic configuration file is missing. Terminating script."
         exit 1
      fi
 
-     if [ ! -f snare.conf.server ]
+     if [ ! -f snare.conf.medium ]
      then
-        echo "The new server configuration file is missing. Terminating script."
+        echo "The new medium configuration file is missing. Terminating script."
+        exit 1
+     fi
+
+     if [ ! -f snare.conf.advanced ]
+     then
+        echo "The new advanced configuration file is missing. Terminating script."
         exit 1
      fi
 
@@ -254,24 +260,44 @@ SNAREC=0
 if [ -f /etc/security/snare.conf ]; then
    SNAREC=1
 fi
- 
+
+if [ -f /etc/init.d/snare ]; then
+	echo "WARNING: It looks as though Snare is already installed."
+	echo
+	echo "Please uninstall Snare first before proceeding: ./uninstall.sh"
+	echo
+	exit
+fi
+
+# Kill off any outstanding pid files.
+if [ -f /var/run/snarecore.pid ]; then
+	rm -f /var/run/snarecore.pid >/dev/null 2>&1
+fi
+
 while [ "$INSTAL" -ne "1" ] && [ "$INSTAL" -ne "2" ] && [ "$INSTAL" -ne "3" ]
 do
   echo 
-  echo "Enter [1] for a workstation install"
-  echo "Enter [2] for a server install"
+  echo "Enter [1] to install a basic starting configuration:"
+  echo "  - login/logout, su, password changes, mounts, system reboots"
+  echo "  - Recommended for workstations"
+  echo "Enter [2] to install an average starting configuration:"
+  echo "  - Basic install, plus process execution events"
+  echo "  - Recommended for servers"
+  echo "Enter [3] to install an advanced starting configuration:"
+  echo "  - Normal install, plus file-based auditing"
   if [ "$SNAREC" -eq "1" ]; then
-     echo "Enter [3] to preserve the EXISTING snare configuration file"
+     echo "Enter [4] to preserve the EXISTING snare configuration file"
   fi
   echo "Enter anything else to terminate the script"
   /usr/ucb/echo -n "Selection: "
     read INSTAL
     case $INSTAL in
-       1) echo "Installing workstation configuration files"; INSTALL_TYPE=1 ;;
-       2) echo "Installing server configuration files"; INSTALL_TYPE=2 ;;
-       3) if [ "$SNAREC" -eq "1" ]; then
+       1) echo "Installing basic configuration files"; INSTALL_TYPE=1 ;;
+       2) echo "Installing average configuration files"; INSTALL_TYPE=2 ;;
+       3) echo "Installing advanced configuration files"; INSTALL_TYPE=3 ;;
+       4) if [ "$SNAREC" -eq "1" ]; then
 		echo "Preserving existing SNARE configuration"
-		INSTALL_TYPE=3
+		INSTALL_TYPE=4
 	  else
 		echo "Script terminating at user request";
 		exit 1;
@@ -293,9 +319,11 @@ echo
 echo "You are about to install Snare on this host."
 echo "Your selections are as follows:"
 if [ $INSTALL_TYPE -eq 1 ]; then
-  echo "Workstation Installation"
+  echo "Basic Installation"
 elif [ $INSTALL_TYPE -eq 2 ]; then
-  echo "Server Installation"
+  echo "Normal Installation"
+elif [ $INSTALL_TYPE -eq 3 ]; then
+  echo "Advanced Installation"
 else
   echo "Preserving existing configuration file."
 fi
@@ -307,7 +335,34 @@ fi
 #  to /etc directory.  
 ########################################################################
 
-if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]; then
+if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ] || [ $INSTALL_TYPE -eq 4 ]; then
+
+   # Kill the audit daemon, if it is alive
+   /usr/sbin/audit -T > /dev/null 2>&1
+   sleep 2
+
+   /etc/init.d/audit stop
+   PID=`/usr/bin/ps -e -u 0|/usr/bin/fgrep auditd|/usr/bin/egrep -v fgrep|/usr/bin/awk '{print $1}'`
+   if [ ! -z "$PID" ] ;  then
+	kill $PID
+        sleep 2
+   fi
+
+   PID=`/usr/bin/ps -e -u 0|/usr/bin/fgrep auditd|/usr/bin/egrep -v fgrep|/usr/bin/awk '{print $1}'`
+   if [ ! -z "$PID" ] ;  then
+	# Die die die...
+	kill -9 $PID
+        sleep 2
+   fi
+
+   # Still active??? Ok.. admit defeat.
+   PID=`/usr/bin/ps -e -u 0|/usr/bin/fgrep auditd|/usr/bin/egrep -v fgrep|/usr/bin/awk '{print $1}'`
+   if [ ! -z "$PID" ] ;  then
+        echo "Warning: Cannot terminate the current audit daemon process."
+        echo "         Please kill auditd manually, and retry the installation."
+	exit
+   fi
+
    echo
    echo "Installing common files..........."
 
@@ -365,7 +420,7 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
      exit 1
    fi
 
-   grep "^0x10000000:" /etc/security/audit_class
+   grep "^0x10000000:" /etc/security/audit_class | egrep -v "0x10000000:ia:" >/dev/null
    RETVAL=$?
    if [ $RETVAL -eq 0 ]; then
 	echo "Cannot modify /etc/security/audit_class - there is already"
@@ -374,8 +429,12 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
         exit 1
    fi
 
-   # Modify, but do not overwrite audit_class
-   echo "0x10000000:ia:intersect alliance snare" >> /etc/security/audit_class
+   grep "0x10000000:ia:" /etc/security/audit_class >/dev/null
+   RETVAL=$?
+   if [ $RETVAL -ne 0 ]; then
+   	# Modify, but do not overwrite audit_class
+   	echo "0x10000000:ia:intersect alliance snare" >> /etc/security/audit_class
+   fi
 
    cat /etc/security/audit_event | nawk -F: '{ print ($1 > 6000) ? $1 ":" $2 ":" $3 ":" $4 ",ia" : $0 }' > /etc/security/audit_event_snare
    mv /etc/security/audit_event_snare /etc/security/audit_event
@@ -395,17 +454,17 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
    fi
 
    # Are we on a sparc or x86 arch?
-   uname -a | grep i86pc >/dev/null
-   if [ $? -eq 0 ]; then
-   	cp ./snare.x86 /usr/bin/snare
-   else
-   	cp ./snare.sparc /usr/bin/snare
-   fi
-   RETVAL=$?
-   if [ $RETVAL -gt 0 ]
-   then
-      echo "Unable to copy the SNARE GUI into /usr/bin. Continuing."
-   fi
+   #uname -a | grep i86pc >/dev/null
+   #if [ $? -eq 0 ]; then
+   #	cp ./snare.x86 /usr/bin/snare
+   #else
+   #	cp ./snare.sparc /usr/bin/snare
+   #fi
+   #RETVAL=$?
+   #if [ $RETVAL -gt 0 ]
+   #then
+   #   echo "Unable to copy the SNARE GUI into /usr/bin. Continuing."
+   #fi
 
    ln /etc/init.d/snare /etc/rc0.d/K33snare
    ln /etc/init.d/snare /etc/rc1.d/K33snare
@@ -432,9 +491,9 @@ fi
 if [ $INSTALL_TYPE -eq 1 ]
 then
    echo
-   echo "Installing workstation configuration files..........."
+   echo "Installing basic configuration files..........."
 
-   cp ./snare.conf.workstation /etc/security/snare.conf
+   cp ./snare.conf.basic /etc/security/snare.conf
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
@@ -457,10 +516,10 @@ fi
 if [ $INSTALL_TYPE -eq 2 ]
 then
    echo
-   echo "Installing server configuration files..........."
+   echo "Installing average configuration files..........."
 
 
-   cp ./snare.conf.server /etc/security/snare.conf
+   cp ./snare.conf.medium /etc/security/snare.conf
    RETVAL=$?
    if [ $RETVAL -gt 0 ]
    then
@@ -471,23 +530,28 @@ then
    chmod 700 /etc/security/snare.conf
 fi
 
-########################################################################
-#  This will kill the old audit daemon, stop the new daemon (if it exists) 
-#  and start the new daemon with the updated parameters. 
-########################################################################
+if [ $INSTALL_TYPE -eq 3 ]
+then
+   echo
+   echo "Installing average configuration files..........."
 
 
-# Kill the audit daemon, if it is alive
-audit -t > /dev/null 2>&1
-sleep 2
+   cp ./snare.conf.advanced /etc/security/snare.conf
+   RETVAL=$?
+   if [ $RETVAL -gt 0 ]
+   then
+     echo "Unable to copy the audit_event file to /etc/security. Terminating script"
+     exit 1 
+   fi
+   chown root:root /etc/security/snare.conf
+   chmod 700 /etc/security/snare.conf
+fi
 
-/etc/init.d/audit stop
 
 echo
 echo "Successfully installed the necessary files. Activating auditing..."
 echo 
 
-
 /etc/init.d/audit start
 /etc/init.d/snare start
 sleep 2
@@ -498,9 +562,16 @@ if [ -z "$PID" ] ;  then
         exit 1;
 fi
 
+# Stop solaris complaining about auditd at reboot
+rm -f /etc/security/audit_data
+ln -s /var/run/snarecore.pid /etc/security/audit_data
+
 echo "Done."
 echo
-if [ $INSTALL_TYPE -ne 3 ]; then
+if [ $INSTALL_TYPE -ne 4 ]; then
+        echo "Snare will also be activated after a reboot via the"
+        echo "init.d/snare startup script."
+	echo
 	echo "Please connect to the local machine using your web browser"
 	echo "using the following URL: http://"`hostname`":6161/"
 	echo "and a userid and password of 'snare'"
