@@ -130,10 +130,12 @@ rm /etc/rc1.d/K33snare 2>/dev/null
 rm /etc/rc2.d/S99zsnare 2>/dev/null
 
 # remove documentation
-rm /usr/share/doc/snare-for-solaris/doc/*
-rmdir /usr/share/doc/snare-for-solaris/doc 2>/dev/null
-rmdir /usr/share/doc/snare-for-solaris 2>/dev/null
-rmdir /usr/share/doc 2>/dev/null
+if [ -d /usr/share/doc/snare-for-solaris ]; then
+	rm /usr/share/doc/snare-for-solaris/doc/*
+	rmdir /usr/share/doc/snare-for-solaris/doc 2>/dev/null
+	rmdir /usr/share/doc/snare-for-solaris 2>/dev/null
+	rmdir /usr/share/doc 2>/dev/null
+fi
 
-rm /var/run/snarecore.pid 2>/dev/null
-rm /etc/security/snare_uninstall.sh
+rm -f /var/run/snarecore.pid 2>/dev/null
+rm -f /etc/security/snare_uninstall.sh
